@@ -22,6 +22,10 @@ class JSONEncoder(json.JSONEncoder):
         if (not isinstance(obj, base_type) and
                 hasattr(obj, '__str__')):
             return str(obj)
+        try:
+            return str(obj)
+        except:
+            pass
         raise TypeError(f'Object of type {val.__class__.__name__} '
                                         f'is not JSON serializable')
 # 調整默認值
